/*
 * File:          move.c
 * Description:   Moves a UMI-RTX robotic arm to joint values specified in a file, continuously.
 * Warning:       Will not exit unless it fails to read the file (or gets killed)
 * Author:        Gijs Kruitbosch
 * Last modified: 2006-06-30
 * Course:        Search, Navigate, Actuate (Zoeken, Sturen en Bewegen), June 2006
 */

#include <stdio.h>
#include <unistd.h>
#include "umi.h"
#include <time.h>

/* Uncomment for debug messages:
 * #define MOVE_DEBUG
 */
#define COUPLED 0

int main(int argc, char *argv[])
{
    FILE *Fp;
    umi_init(); // <-- do we need this? Need to ask Arnoud...
    while (1)
    {
        Fp = fopen("/home/gkruitbo/pub/joints.txt", "r");

        // null pointers suck:
        if (!Fp)
        {
            printf("Failure to read input from file! Exiting...");
            fclose(Fp);
            return 1;
        }

        // get us the joint values
        double zed, shoulder, elbow, yaw, pitch, roll, grip;
        time_t mytime = time(0);
        printf("%s: Taking 7 doubles from the file /home/gkruitbo/pub/joints.txt ...\n", asctime(localtime(&mytime)));
        int i = fscanf(Fp, "%lf %lf %lf %lf %lf %lf %lf", &zed, &shoulder, &elbow, &yaw, &pitch, &roll, &grip);
        if (i != 7)
        {
            printf("Failure to read input from file! Exiting...");
            fclose(Fp);
            return 1;
        }

#ifdef MOVE_DEBUG
        // Debug the values the app reads:
        printf("Zed: %lf\n", zed);
        printf("Shoulder: %lf\n", shoulder);
        printf("Elbow: %lf\n", elbow);
        printf("Yaw: %lf\n", yaw);
        printf("Pitch: %lf\n", pitch);
        printf("Roll: %lf\n", roll);
        printf("Grip: %lf\n", grip);
#endif
        fclose(Fp);

#ifdef MOVE_DEBUG
        printf("Moving robot...");
#endif
        // What we've all been waiting for: move the robot!
        umi_move(zed, shoulder, elbow, yaw, pitch, roll, grip);

#ifdef MOVE_DEBUG
        printf("done.\n");
#endif
        // Back to hibernating
        sleep(2);
    }
    return 0;
}

